@@ -1,6 +1,7 @@
 var _ = require('underscore');
 var fs = require('fs');
 var path = require('path');
+var yaml = require('js-yaml');
 var utils = require('../utils.js');
 
 var logger = require('../logging.js');
@@ -47,6 +48,11 @@ var create_key_name = function(branch, file, ref) {
   if (branch.source_root && !ref) {
     file = file.substring(branch.source_root.length + 1);
   }
+
+  // Ignore file extensoion on demand
+  if (branch.ignore_file_extension) {
+    file = file.substr(0, file.lastIndexOf("."));
+  }
   key_parts.push(file);
   return key_parts.join('/');
 };
@@ -99,7 +105,7 @@ var file_modified = function(branch, file, cb) {
       fs.readFile(file_path, {encoding: 'utf8'}, function (err, body) {
         /* istanbul ignore if */
         if (err) return cb('Failed to read key ' + file_path + ' due to ' + err);
-        var body = body ? body.trim() : '';
+        body = body ? body.trim() : '';
         try {
           var obj = JSON.parse(body);
           populate_kvs_from_object(branch, create_key_name(branch, file), obj, cb);
@@ -111,7 +117,6 @@ var file_modified = function(branch, file, cb) {
   };
 
   var handle_properties_kv_file = function(file_path, common_properties_relative_path, cb) {
-
     function extract_and_populate_properties(file_body, common_body, cb) {
       utils.load_properties(file_body, common_body, function (error, obj) {
         if (error) {
@@ -143,11 +148,26 @@ var file_modified = function(branch, file, cb) {
     });
   };
 
+  var handle_yaml_kv_file = function(file_path, cb) {
+    fs.readFile(file_path, {encoding: 'utf8'}, function (err, body) {
+      /* istanbul ignore if */
+      if (err) return cb('Failed to read key ' + file_path + ' due to ' + err);
+      body = body ? body.trim() : '';
+      try {
+        var obj = yaml.safeLoad(body);
+        populate_kvs_from_object(branch, create_key_name(branch, file), obj, cb);
+      } catch (e) {
+        logger.warn("Failed to parse .yaml file " + file + ".  Using body string as a KV.");
+        write_content_to_consul(create_key_name(branch, file), body, cb);
+      }
+    });
+  };
+
   var handle_as_flat_file = function(fqf, branch, file, cb) {
     fs.readFile(fqf, {encoding: 'utf8'}, function (err, body) {
       /* istanbul ignore if */
       if (err) return cb('Failed to read key ' + fqf + ' due to ' + err);
-      var body = body ? body.trim() : '';
+      body = body ? body.trim() : '';
       write_content_to_consul(create_key_name(branch, file), body, cb);
     });
   };
@@ -160,6 +180,11 @@ var file_modified = function(branch, file, cb) {
         if (err) return cb('Failed to delete key ' + key_name + ' due to ' + err);
         handle_json_kv_file(fqf, cb);
       });
+    } else if (file.endsWith('.yaml') || file.endsWith('.yml')) {
+      file_deleted(branch, file, function (err) {
+        if (err) return cb('Failed to delete key ' + key_name + ' due to ' + err);
+        handle_yaml_kv_file(fqf, cb);
+      });
     } else if (file.endsWith('.properties')) {
       file_deleted(branch, file, function (err) {
         if (err) return cb('Failed to delete key ' + key_name + ' due to ' + err);
