@@ -64,7 +64,7 @@ exports.extractTags = function (repo_url, cwd, cb) {
   run_command('git ls-remote --tags' + ' ' + repo_url, cwd, function (err, output) {
     var extracted_tags = [];
     var one_tag;
-    var tag_regex = /refs\/tags\/([a-z0-9]*)\^\{\}/ig;
+    var tag_regex = /refs\/tags\/(.*)\^\{\}/ig;
     while ((one_tag = tag_regex.exec(output)) !== null) {
       extracted_tags.push(one_tag[1]);
     }
