@@ -113,10 +113,6 @@ exports.createRepos = function(config, cb) {
             return error_handler("Failed to load repo " + repo_config.name + " due to " + err);
           }
 
-          if (repo_config.support_tags == true) {
-            exports.repos[repo_config.name].createNewTagsAsBranch();
-          }
-
           logger.info("Loaded repo %s", repo_config.name);
           cb();
         });
